extern const char **_dictionary_redhat;
#ifndef DICTIONARY_REQUEST
	#define DICTIONARY_REQUEST \
	const char **_dictionary_redhat;\
	TRANSLATE_SYSTEM_REQ _dictionary_req_redhat("redhat",_dictionary_redhat,52,3);\
	void dummy_dict_redhat(){}
#endif
#ifndef MSG_U
	#define MSG_U(id,m)	_dictionary_redhat[id]
	#define MSG_B(id,m,n)	_dictionary_redhat[id]
	#define MSG_R(id)	_dictionary_redhat[id]
	#define P_MSG_U(id,m)	new_trans_notload(_dictionary_redhat,id)
	#define P_MSG_B(id,m,n)	new_trans_notload(_dictionary_redhat,id)
	#define P_MSG_R(id)	new_trans_notload(_dictionary_redhat,id)
#endif
#define T_USAGE	0
#define I_REMOVING	1
#define T_AUTHENTICATE	2
#define I_AUTHREQ	3
#define T_NEWPASS	4
#define I_NEWPASS	5
#define I_DISABLED	6
#define I_ENABLED	7
#define N_WRONGVERSION	8
#define F_STATUS	9
#define T_ONESERVICE	10
#define I_ONESERVICE	11
#define B_START	12
#define B_STOP	13
#define B_RESTART	14
#define I_SYSVENABLED	15
#define I_SYSVDISABLED	16
#define I_RUNNING	17
#define T_SERVNAME	18
#define B_STATUS	19
#define P_CTRLSERV	20
#define F_CONFIGURED	21
#define F_DESCRIPTION	22
#define F_PKGVER	23
#define B_PKGINFO	24
#define F_PACKAGE	25
#define I_NOMANAGERPM	26
#define I_BASE	27
#define I_RUNLEVELS	28
#define I_LEVEL0	29
#define I_LEVEL1	30
#define I_LEVEL2	31
#define I_LEVEL3	32
#define I_LEVEL4	33
#define I_LEVEL5	34
#define I_LEVEL6	35
#define F_RUNLEVEL	36
#define I_CUSTOMLEVELS	37
#define I_RECOMMENDED	38
#define I_BINDDESC	39
#define I_IMAPDESC	40
#define I_DHCPDESC	41
#define I_NFSDESC	42
#define Q_INSTALLPKG	43
#define T_INSTALLPKG	44
#define P_INSTALLPKG	45
#define I_XFSDESC	46
#define I_PORTMAPDESC	47
#define I_YPSERVDESC	48
#define I_MDKCD	49
#define I_RHCD	50
#define I_YPCLIENTDESC	51
